import typer
import requests
import emoji
from tinydb import TinyDB, Query
import os
from dotenv import load_dotenv
load_dotenv()

app = typer.Typer()

db = TinyDB("db.json")

API_KEY = os.getenv("API_KEY")

@app.command()
def now(city_nickname: str):
    city = db.search(Query().city == city_nickname)
    if city:
        lat = city[0]["coordinates"][0]
        lon = city[0]["coordinates"][1]
        r = requests.get(f"https://api.openweathermap.org/data/2.5/weather?lat={lat}&units=metric&lon={lon}&limit=1&appid={API_KEY}")
        content = r.json()
        current_temperature = content["main"]["temp"]
        weather = content["weather"][0]["main"]
        emoji = get_emoji(weather)
        print(emoji + "  " + str(current_temperature) + "°C")
    else:
        print("City not added!")


@app.command()
def add(city_nickname: str):
    city_nickname_exists = db.search(Query().city == city_nickname)
    if not city_nickname_exists:
        country = input("Type the country name or code (ISO3166): ")
        state = input("Type the state code (only for US): ")
        city = input("Type the city name: ")
        r = requests.get(f"http://api.openweathermap.org/geo/1.0/direct?q={city},{state},{country}&limit=1&appid={API_KEY}")
        lat = r.json()[0]["lat"]
        lon = r.json()[0]["lon"]
        db.insert({"city": city_nickname, "coordinates": [lat,lon]})
    else:
        print("City already added!")


def get_emoji(weather: str):
    match weather:
        case "Clouds":
            return emoji.emojize(":cloud:")
        case "Rain":
            return emoji.emojize(":cloud-with-rain:")
        case "Clear":
            return emoji.emojize(":sun:")